==> tamejs-0.1.5.tgz: package/test/cases/14.out.js <==
var tame = require('tamejs').runtime;
var __tame_fn_0 = function (__tame_k) {
    var assert = require ( "assert" ) ;
    function MyClass (lim) {
        this ._i = 0 ;
        this ._lim = lim ;
        this .iter =
        function  () {
            return this ._i;
        }
        this .next =
        function  (cb) {
            var __tame_this = this;
            var __tame_fn_9 = function (__tame_k) {
                var done = false ;
                var __tame_fn_1 = function (__tame_k) {
                    var __tame_fn_2 = function (__tame_k) {
                        var __tame_fn_3 = function (__tame_k) {
                            done = true ;
                            tame.callChain([__tame_k]);
                        };
                        var __tame_fn_4 = function (__tame_k) {
                            var __tame_fn_5 = function (__tame_k) {
                                var __tame_ev = new tame.Event (__tame_k);
                                var __tame_fn_6 = function (__tame_k) {
                                    setTimeout ( __tame_ev.mkevent ( ) , 3 * Math .random ( ) ) ;
                                    tame.callChain([__tame_k]);
                                };
                                __tame_fn_6(tame.end);
                                __tame_ev.trigger();
                            };
                            var __tame_fn_7 = function (__tame_k) {
                                __tame_this ._i ++ ;
                                tame.callChain([__tame_k]);
                            };
                            tame.callChain([__tame_fn_5, __tame_fn_7, __tame_k]);
                        };
                        if (__tame_this ._i >= __tame_this ._lim) {
                            tame.callChain([__tame_fn_3, __tame_k]);
                        } else {
                            tame.callChain([__tame_fn_4, __tame_k]);
                        }
                    };
                    var __tame_fn_8 = function (__tame_k) {
                        cb ( done ) ;
                        tame.callChain([__tame_k]);
                    };
                    tame.callChain([__tame_fn_2, __tame_fn_8, __tame_k]);
                };
                tame.callChain([__tame_fn_1, __tame_k]);
            };
            tame.callChain([__tame_fn_9, __tame_k]);
        }
        ;
    }
    ;
    
    var obj = null ;
    var n = 30 ;
    
    exports [ "test of 'this' inside of a tamed class" ] = {
    
    run :
    function  (cb) {
        var __tame_this = this;
        var __tame_fn_19 = function (__tame_k) {
            obj = new MyClass ( n ) ;
            var go = true ;
            var __tame_fn_10 = function (__tame_k) {
                var __tame_fn_11 = function (__tame_k) {
                    var __tame_k_implicit =  {};
                    var __tame_fn_12 = function (__tame_k) {
                        if (go) {
                            var __tame_fn_17 = function (__tame_k) {
                                var res = [ ] ;
                                var __tame_fn_13 = function (__tame_k) {
                                    var __tame_fn_14 = function (__tame_k) {
                                        var __tame_ev = new tame.Event (__tame_k);
                                        var __tame_fn_15 = function (__tame_k) {
                                            obj .next ( __tame_ev.mkevent ( res ) ) ;
                                            tame.callChain([__tame_k]);
                                        };
                                        __tame_fn_15(tame.end);
                                        __tame_ev.trigger();
                                    };
                                    var __tame_fn_16 = function (__tame_k) {
                                        go = !res [ 0 ] ;
                                        tame.callChain([__tame_k]);
                                    };
                                    tame.callChain([__tame_fn_14, __tame_fn_16, __tame_k]);
                                };
                                tame.callChain([__tame_fn_13, __tame_k]);
                            };
                            tame.callChain([__tame_fn_17, __tame_fn_12, __tame_k]);
                        } else {
                            tame.callChain([__tame_k]);
                        }
                    };
                    __tame_k_implicit.k_break = __tame_k;
                    __tame_k_implicit.k_continue = function() { __tame_fn_12(__tame_k); };
                    tame.callChain([__tame_fn_12, __tame_k]);
                };
                var __tame_fn_18 = function (__tame_k) {
                    cb ( ) ;
                    tame.callChain([__tame_k]);
                };
                tame.callChain([__tame_fn_11, __tame_fn_18, __tame_k]);
            };
            tame.callChain([__tame_fn_10, __tame_k]);
        };
        tame.callChain([__tame_fn_19, __tame_k]);
    }
    ,
    
    check :
    function  () {
        assert .equal ( obj .iter ( ) , n , "achieved n iterations" ) ;
    }
    } ;
    tame.callChain([__tame_k]);
};
__tame_fn_0 (tame.end);

==> tamejs-0.2.1.tgz: package/test/cases/14.out.js <==
var tame = require('tamejs').runtime;
var __tame_fn_0 = function (__tame_k) {
    var assert = require ( "assert" ) ;
    function MyClass (lim) {
        this ._i = 0 ;
        this ._lim = lim ;
        this .iter =
        function  () {
            return this ._i;
        }
        this .next =
        function  (cb) {
            var __tame_this = this;
            var __tame_fn_9 = function (__tame_k) {
                var done = false ;
                var __tame_fn_1 = function (__tame_k) {
                    var __tame_fn_2 = function (__tame_k) {
                        var __tame_fn_3 = function (__tame_k) {
                            done = true ;
                            tame.callChain([__tame_k]);
                        };
                        var __tame_fn_4 = function (__tame_k) {
                            var __tame_fn_5 = function (__tame_k) {
                                var __tame_ev = new tame.Event (__tame_k);
                                var __tame_fn_6 = function (__tame_k) {
                                    setTimeout (
                                    __tame_ev.mkevent ()
                                    , 3 * Math .random ( ) ) ;
                                    tame.callChain([__tame_k]);
                                };
                                __tame_fn_6(tame.end);
                                __tame_ev.trigger();
                            };
                            var __tame_fn_7 = function (__tame_k) {
                                __tame_this ._i ++ ;
                                tame.callChain([__tame_k]);
                            };
                            tame.callChain([__tame_fn_5, __tame_fn_7, __tame_k]);
                        };
                        if (__tame_this ._i >= __tame_this ._lim) {
                            tame.callChain([__tame_fn_3, __tame_k]);
                        } else {
                            tame.callChain([__tame_fn_4, __tame_k]);
                        }
                    };
                    var __tame_fn_8 = function (__tame_k) {
                        cb ( done ) ;
                        tame.callChain([__tame_k]);
                    };
                    tame.callChain([__tame_fn_2, __tame_fn_8, __tame_k]);
                };
                tame.callChain([__tame_fn_1, __tame_k]);
            };
            tame.callChain([__tame_fn_9, __tame_k]);
        }
        ;
    }
    ;
    
    var obj = null ;
    var n = 30 ;
    
    exports [ "test of 'this' inside of a tamed class" ] = {
    
    run :
    function  (cb) {
        var __tame_this = this;
        var __tame_fn_19 = function (__tame_k) {
            obj = new MyClass ( n ) ;
            var go = true ;
            var __tame_fn_10 = function (__tame_k) {
                var __tame_fn_11 = function (__tame_k) {
                    var __tame_k_implicit =  {};
                    var __tame_fn_12 = function (__tame_k) {
                        if (go) {
                            var __tame_fn_17 = function (__tame_k) {
                                var res = [ ] ;
                                var __tame_fn_13 = function (__tame_k) {
                                    var __tame_fn_14 = function (__tame_k) {
                                        var __tame_ev = new tame.Event (__tame_k);
                                        var __tame_fn_15 = function (__tame_k) {
                                            obj .next (
                                            __tame_ev.mkevent (function (args) {
                                                res = tame.assign (args, res);
                                            })
                                            ) ;
                                            tame.callChain([__tame_k]);
                                        };
                                        __tame_fn_15(tame.end);
                                        __tame_ev.trigger();
                                    };
                                    var __tame_fn_16 = function (__tame_k) {
                                        go = !res [ 0 ] ;
                                        tame.callChain([__tame_k]);
                                    };
                                    tame.callChain([__tame_fn_14, __tame_fn_16, __tame_k]);
                                };
                                tame.callChain([__tame_fn_13, __tame_k]);
                            };
                            tame.callChain([__tame_fn_17, __tame_fn_12, __tame_k]);
                        } else {
                            tame.callChain([__tame_k]);
                        }
                    };
                    __tame_k_implicit.k_break = __tame_k;
                    __tame_k_implicit.k_continue = function() { __tame_fn_12(__tame_k); };
                    tame.callChain([__tame_fn_12, __tame_k]);
                };
                var __tame_fn_18 = function (__tame_k) {
                    cb ( ) ;
                    tame.callChain([__tame_k]);
                };
                tame.callChain([__tame_fn_11, __tame_fn_18, __tame_k]);
            };
            tame.callChain([__tame_fn_10, __tame_k]);
        };
        tame.callChain([__tame_fn_19, __tame_k]);
    }
    ,
    
    check :
    function  () {
        assert .equal ( obj .iter ( ) , n , "achieved n iterations" ) ;
    }
    } ;
    tame.callChain([__tame_k]);
};
__tame_fn_0 (tame.end);
